==> writer-7.x-1.0.tar.gz: writer/page.tpl.php <==
<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 * @see html.tpl.php
 */
?>

<div id="wrapper">
  <?php print render($page['pre_header']); ?>
  <header id="site-header">
  	<div class="head-wrap clearfix">
      <nav>
        <?php print theme('links__system_main_menu', array(
          'links' => $main_menu,
          'attributes' => array(
            'id' => 'main-menu',
            'class' => array(
              'links', 'inline', 'clearfix',
            ),
          ),
          'heading' => t('Main menu'),
        )); ?>
      </nav>
	    <h1 id="site-name">
	     <a href="<?php print $front_page; ?>"><?php print $site_name; ?></a>
	    </h1>
	  </div>
	<?php print render($page['header']); ?>
  </header>
  <?php print render($page['post_header']); ?>
  <section class="main-content">
  	<?php if ($page['highlighted']): ?><div id="highlighted"><?php print render($page['highlighted']); ?></div><?php endif; ?>
  	<a id="main-content"></a>
  	<?php print render($title_prefix); ?>
    <?php if ($title): ?><h1 class="title" id="page-title"><?php print $title; ?></h1><?php endif; ?>
    <?php print render($title_suffix); ?>
    <?php if ($tabs): ?><div class="tabs"><?php print render($tabs); ?></div><?php endif; ?>
    <?php print render($page['help']); ?>
    <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
    <?php print render($page['content']); ?>
  </section>
  <footer>
  	<?php print render($page['footer_top']); ?>
  	<?php if($page['footer_left'] || $page['footer_right']): ?>
  	  <div class="foot-mid-wrap clearfix">
		    <?php if($page['footer_left']): ?>
		      <div id="footer_left">
		        <?php print render($page['footer_left']); ?>
		      </div>
		    <?php endif; ?>
		    <?php if($page['footer_right']): ?>
			    <div id="footer_right">
			      <?php print render($page['footer_right']); ?>
			    </div>
		    <?php endif; ?>
  		</div>
  	<?php endif; ?>
  	<?php print render($page['footer_bottom']); ?>
  	<div class="foot-wrap clearfix">
      <nav class="foot-links">
    		<?php print theme('links__system_secondary_menu', array(
          'links' => $secondary_menu,
          'attributes' => array(
            'id' => 'secondary-menu',
            'class' => array(
              'links', 'inline', 'clearfix',
            ),
          ),
          'heading' => t('Footer menu'),
        )); ?>
    	</nav>
      <?php if($page['footer_message']): ?>
        <div class="footer-msg">
          <?php print render($page['footer_message']); ?>
        </div>
      <?php endif; ?>
    </div>
  </footer>
</div> <!-- end wrapper -->

==> writer-7.x-2.2.tar.gz: writer/page.tpl.php <==
<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 * @see html.tpl.php
 */
?>

<div id="wrapper" class="<?php print $wrapper_classes; ?>" <?php print $content_width_rule ?>>
  <?php print render($page['pre_header']); ?>
  <header id="site-header">
  	<div class="head-wrap clearfix">
      <?php if ($logo): ?>
        <div class="logo-wrap">
          <a href="<?php print $front_page; ?>" rel="home" id="logo">
            <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
          </a>
        </div>
      <?php endif; ?>
      <?php if ($site_name || $site_slogan): ?>
        <hgroup class="site-name-wrap">
          <?php if ($site_name): ?>
    	      <h1 id="site-name">
    	        <a href="<?php print $front_page; ?>"><?php print $site_name; ?></a>
    	      </h1>
          <?php endif; ?>
          <?php if ($site_slogan): ?>
            <h2 id="site-slogan"><?php print $site_slogan; ?></h2>
          <?php endif; ?>
        </hgroup>
      <?php endif; ?>
      <nav id="main-nav">
        <?php print theme('links__system_main_menu', array(
          'links' => $main_menu,
          'attributes' => array(
            'id' => 'main-menu',
            'class' => array(
              'links', 'inline', 'clearfix',
            ),
          ),
          'heading' => t('Main menu'),
        )); ?>
      </nav>
	  </div>
	<?php print render($page['header']); ?>
  </header>
  <?php print render($page['post_header']); ?>
  <?php print $messages; ?>
  <section class="main-content">
    <?php if ($page['highlighted']): ?><div id="highlighted"><?php print render($page['highlighted']); ?></div><?php endif; ?>
  	<a id="main-content"></a>
  	<?php print render($title_prefix); ?>
    <?php if ($title): ?><h1 class="title" id="page-title"><?php print $title; ?></h1><?php endif; ?>
    <?php print render($title_suffix); ?>
    <?php if ($tabs && ($tabs['#primary'] || $tabs['#secondary'])): ?><div class="tabs"><?php print render($tabs); ?></div><?php endif; ?>
    <?php print render($page['help']); ?>
    <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
    <?php print render($page['content']); ?>
  </section>
  <footer class="page-footer">
  	<?php print render($page['footer_top']); ?>
  	<?php if($page['footer_left'] || $page['footer_right']): ?>
  	  <div class="foot-mid-wrap clearfix">
		    <?php if($page['footer_left']): ?>
		      <div id="footer_left">
		        <?php print render($page['footer_left']); ?>
		      </div>
		    <?php endif; ?>
		    <?php if($page['footer_right']): ?>
			    <div id="footer_right">
			      <?php print render($page['footer_right']); ?>
			    </div>
		    <?php endif; ?>
  		</div>
  	<?php endif; ?>
  	<?php print render($page['footer_bottom']); ?>
  	<div class="foot-wrap clearfix">
      <nav class="foot-links">
    		<?php print theme('links__system_secondary_menu', array(
          'links' => $secondary_menu,
          'attributes' => array(
            'id' => 'secondary-menu',
            'class' => array(
              'links', 'inline', 'clearfix',
            ),
          ),
          'heading' => t('Footer menu'),
        )); ?>
    	</nav>
      <?php if($page['footer_message']): ?>
        <div class="footer-msg">
          <?php print render($page['footer_message']); ?>
        </div>
      <?php endif; ?>
    </div>
  </footer>
</div> <!-- end wrapper -->
